summaryrefslogtreecommitdiffstats
path: root/writefrudata.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'writefrudata.cpp')
-rw-r--r--writefrudata.cpp15
1 files changed, 10 insertions, 5 deletions
diff --git a/writefrudata.cpp b/writefrudata.cpp
index 00d5b5b..c5f2539 100644
--- a/writefrudata.cpp
+++ b/writefrudata.cpp
@@ -15,7 +15,6 @@
#include <mapper.h>
#include "frup.hpp"
#include "fru-area.hpp"
-#include "fru-gen.hpp"
#include <sdbusplus/server.hpp>
// OpenBMC System Manager dbus framework
@@ -24,13 +23,19 @@ const char *sys_intf_name = "org.openbmc.managers.System";
extern const FruMap frus;
+using Property = std::string;
+using Value = sdbusplus::message::variant<bool, int64_t, std::string>;
+// Association between property and its value
+using PropertyMap = std::map<Property, Value>;
+
+using Interface = std::string;
// Association between interface and the dbus property
-using InterfaceList = std::map<std::string,
- std::map<std::string, std::string>>;
+using InterfaceMap = std::map<Interface, PropertyMap>;
-// Association between property and its value
-using PropertiesList = std::map<std::string, std::string>;
+using Object = sdbusplus::message::object_path;
+// Association between object and the interfaces.
+using ObjectMap = std::map<Object, InterfaceMap>;
//----------------------------------------------------------------
// Constructor
OpenPOWER on IntegriCloud